unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls, ZylGSM, ComCtrls;

type
  TForm1 = class(TForm)
    Memo: TMemo;
    btnOpen: TButton;
    txtNo: TEdit;
    btnSendStr: TButton;
    btnClose: TButton;
    lstPort: TListBox;
    lstBaudRate: TListBox;
    ZylGSM: TZylGSM;
    btnDial: TButton;
    btnAnswer: TButton;
    btnSendSMSText: TButton;
    txtMessage: TMemo;
    btnTerminate: TButton;
    btnSendSMSPDU: TButton;
    btnDetect: TButton;
    lblDetect: TLabel;
    btnCancel: TButton;
    rgMessageFormat: TRadioGroup;
    btnGetAllSMS: TButton;
    lvMessages: TListView;
    rgStorage: TRadioGroup;
    btnDeleteSms: TButton;
    cbFlash: TCheckBox;
    lvContacts: TListView;
    btnLoadContacts: TButton;
    btnDelteContact: TButton;
    btnDetectAll: TButton;
    procedure ZylGSMReceive(Sender: TObject; Buffer: String);
    procedure btnOpenClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure btnSendStrClick(Sender: TObject);
    procedure btnCloseClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure ZylGSMDisconnect(Sender: TObject; Port: TCommPort);
    procedure ZylGSMConnect(Sender: TObject; Port: TCommPort);
    procedure btnDialClick(Sender: TObject);
    procedure btnAnswerClick(Sender: TObject);
    procedure btnSendSMSTextClick(Sender: TObject);
    procedure btnTerminateClick(Sender: TObject);
    procedure btnSendSMSPDUClick(Sender: TObject);
    procedure ZylGSMRing(Sender: TObject; CallerNumber: String);
    procedure ZylGSMNewMessage(Sender: TObject; Storage: String;
      Index: Integer);
    procedure ZylGSMReadMessage(Sender: TObject; MessageText: WideString; PhoneNumber,
      CenterNumber: String; TimeStamp: TDateTime; TimeZone, Status, Index: Integer);
    procedure btnDetectClick(Sender: TObject);
    procedure ZylGSMDetect(Sender: TObject; const Port: TCommPort;
      const BaudRate: TBaudRate; var Cancel: Boolean);
    procedure btnCancelClick(Sender: TObject);
    procedure rgMessageFormatClick(Sender: TObject);
    procedure ZylGSMFault(Sender: TObject; Port: TCommPort);
    procedure ZylGSMError(Sender: TObject; Buffer: String);
    procedure btnGetAllSMSClick(Sender: TObject);
    procedure btnDeleteSmsClick(Sender: TObject);
    procedure btnLoadContactsClick(Sender: TObject);
    procedure ZylGSMContactLoad(Sender: TObject; const index: Integer;
      const name, phoneNumber, location: String);
    procedure btnDelteContactClick(Sender: TObject);
    procedure FormDblClick(Sender: TObject);
    procedure btnDetectAllClick(Sender: TObject);
    procedure ZylGSMIdle(Sender: TObject);
    procedure ZylGSMResume(Sender: TObject);
    procedure ZylGSMTimeout(Sender: TObject);
    procedure rgStorageClick(Sender: TObject);
  private
    { Private declarations }
    FCancelDetect: Boolean;
    FSmsListStorage: String;
    FContactListStorage: String;

  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.ZylGSMReceive(Sender: TObject; Buffer: String);
begin
  Memo.Lines.Add(Buffer);
end;

procedure TForm1.btnOpenClick(Sender: TObject);
var
  gsmCapabilities: Word;
begin
  ZylGSM.AutoReconnect := true;
  ZylGSM.Port := ZylGSM.StringToCommPort(lstPort.Items[lstPort.ItemIndex]);
  if ZylGSM.Port = spCustom then
    ZylGSM.CustomPortName := lstPort.Items[lstPort.ItemIndex];
  ZylGSM.BaudRate := ZylGSM.IntToBaudRate(
  StrToInt(lstBaudRate.Items[lstBaudRate.ItemIndex]));
  ZylGSM.MessageFormat := TMessageFormat(rgMessageFormat.ItemIndex);  
  if not ZylGSM.Open() then
    Exit;

  Sleep(300);

  //Test GSM modem capabilities
  {Memo.Lines.Add('GSM modem capabilities:');
  gsmCapabilities := ZylGSM.TestGSMModemCapabilities();
  if gsmCapabilities and 2 > 0 then
    Memo.Lines.Add('Display Caller Number: Yes')
  else
    Memo.Lines.Add('Display Caller Number: No');

  if gsmCapabilities and 4 > 0 then
    Memo.Lines.Add('GSM 7-bit alphabet support: Yes')
  else
    Memo.Lines.Add('GSM 7-bit alphabet support: No');

  if gsmCapabilities and 8 > 0 then
    Memo.Lines.Add('SMS Text mode: Yes')
  else
    Memo.Lines.Add('SMS Text mode: No');

  if gsmCapabilities and 16 > 0 then
    Memo.Lines.Add('SMS PDU mode: Yes')
  else
    Memo.Lines.Add('SMS PDU mode: No');

  if gsmCapabilities and 32 > 0 then
    Memo.Lines.Add('New SMS notification: Yes')
  else
    Memo.Lines.Add('New SMS notification: No');

  if gsmCapabilities and 64 > 0 then
    Memo.Lines.Add('Read SMS: Yes')
  else
    Memo.Lines.Add('Read SMS: No');

  if gsmCapabilities and 128 > 0 then
    Memo.Lines.Add('Send SMS: Yes')
  else
    Memo.Lines.Add('Send SMS: No');   }
end;

procedure TForm1.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  ZylGSM.Close();
end;

procedure TForm1.btnSendStrClick(Sender: TObject);
var
  listResult: TStringList;
  i: Integer;
begin
  ZylGSM.SendString(txtMessage.Text + #13);
  {listResult := TStringList.Create;
  ZylGSM.ExecuteATCommand(txtMessage.Text, listResult);
  for i := 0 to listResult.Count -1 do
    Memo.Lines.Add(listResult[i]);}
end;

procedure TForm1.btnCloseClick(Sender: TObject);
begin
  ZylGSM.Close;
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  lstPort.Items.Clear;
  ZylGSM.GetExistingCommPortNames(lstPort.Items);
  lstBaudRate.ItemIndex := 9;
  FSmsListStorage := Phone_SIM;
  FContactListStorage := Phone_SIM;
  ZylGSM.DetectionMethod := dmSendSms;
  if rgStorage.ItemIndex = 0 then
    ZylGSM.StorageLocation := Phone_SIM
  else
    ZylGSM.StorageLocation := Phone_Memory;
end;

procedure TForm1.ZylGSMDisconnect(Sender: TObject; Port: TCommPort);
begin
  Memo.Lines.Add('Disconnected from ' + ZylGSM.CommPortToString(Port));
end;

procedure TForm1.ZylGSMConnect(Sender: TObject; Port: TCommPort);
begin
  Memo.Lines.Add('Connected to ' + ZylGSM.CommPortToString(Port));
end;

procedure TForm1.btnDialClick(Sender: TObject);
begin
  if ZylGSM.DialVoice(txtNo.Text) then
    Memo.Lines.Add('Dial success: ' + txtNo.Text)
  else
    Memo.Lines.Add('Dial failed: ' + txtNo.Text);
end;

procedure TForm1.btnAnswerClick(Sender: TObject);
begin
  if ZylGSM.AnswerCall then
    Memo.Lines.Add('Answer success.')
  else
    Memo.Lines.Add('Answer failed.');
end;

procedure TForm1.btnSendSMSTextClick(Sender: TObject);
begin
  if ZylGSM.SendSmsAsText(txtNo.Text, '', txtMessage.Text) then
    Memo.Lines.Add('Successfully sent to : ' + txtNo.Text)
  else
    Memo.Lines.Add('Not sent to : ' + txtNo.Text);
end;

procedure TForm1.btnTerminateClick(Sender: TObject);
begin
  if ZylGSM.TerminateCall then
    Memo.Lines.Add('Terminate success.')
  else
    Memo.Lines.Add('Terminate failed.')
end;

procedure TForm1.btnSendSMSPDUClick(Sender: TObject);
begin
  if ZylGSM.SendSmsAsPDU(txtNo.Text, '', txtMessage.Text, meAuto, cbFlash.Checked) then
    Memo.Lines.Add('Successfully sent to : ' + txtNo.Text)
  else
    Memo.Lines.Add('Not sent to : ' + txtNo.Text);
end;

procedure TForm1.ZylGSMRing(Sender: TObject; CallerNumber: String);
begin
  Memo.Lines.Add('RING EVENT: ' + CallerNumber);
end;

procedure TForm1.ZylGSMNewMessage(Sender: TObject; Storage: String;
  Index: Integer);
begin
  Memo.Lines.Add('New SMS');
end;

procedure TForm1.ZylGSMReadMessage(Sender: TObject; MessageText: WideString;
  PhoneNumber, CenterNumber: String; TimeStamp: TDateTime; TimeZone, Status, Index: Integer);
var
  item: TListItem;
begin
  Memo.Lines.Add('SMS: ' + MessageText);
  Memo.Lines.Add('Caller: ' + PhoneNumber);
  Memo.Lines.Add('Center: ' + CenterNumber);
  Memo.Lines.Add('Time Stamp: ' + DateTimeToStr(TimeStamp));
  Memo.Lines.Add('Time Zone: ' + IntToStr(TimeZone));
  Memo.Lines.Add('Status: ' + IntToStr(Status));
  Memo.Lines.Add('Index: ' + IntToStr(Index));

  if ZylGSM.IsListing then
  begin
    item := lvMessages.Items.Add();
    item.Caption := DateTimeToStr(TimeStamp);
    item.SubItems.Add(PhoneNumber);
    item.SubItems.Add(MessageText);
    item.SubItems.Add(IntToStr(Status));
    item.SubItems.Add(IntToStr(Index));
  end;
end;

procedure TForm1.btnDetectClick(Sender: TObject);
var
  pPort: string;
  pBaudRate: TBaudRate;
begin
  FCancelDetect := False;
  if ZylGSM.FastDetectGSM(pPort, pBaudRate) then
  begin
    ShowMessage('Detected: ' + pPort +
      ' BaudRate = ' + IntToStr(ZylGSM.BaudRateToInt(pBaudRate)));
    lstPort.ItemIndex := lstPort.Items.IndexOf(pPort);
    lstBaudRate.ItemIndex := lstBaudRate.Items.IndexOf(IntToStr(ZylGSM.BaudRateToInt(pBaudRate)));
  end
  else
  begin
    ShowMessage('No GSM detected.');
  end;
  lblDetect.Caption := ''
end;

procedure TForm1.ZylGSMDetect(Sender: TObject; const Port: TCommPort;
  const BaudRate: TBaudRate; var Cancel: Boolean);
begin
  lblDetect.Caption := 'Detecting - Port: ' + ZylGSM.CommPortToString(Port) +
      ' BaudRate: ' + IntToStr(ZylGSM.BaudRateToInt(BaudRate));
  Cancel := FCancelDetect;
end;

procedure TForm1.btnCancelClick(Sender: TObject);
begin
  FCancelDetect := True;
end;

procedure TForm1.rgMessageFormatClick(Sender: TObject);
begin
  ZylGSM.MessageFormat := TMessageFormat(rgMessageFormat.ItemIndex);
end;

procedure TForm1.ZylGSMFault(Sender: TObject; Port: TCommPort);
begin
  Memo.Lines.Add('Faulted: ' + ZylGSM.CommPortToString(Port));
end;

procedure TForm1.ZylGSMError(Sender: TObject; Buffer: String);
begin
  Memo.Lines.Add('----Error-----'#13#10 + Buffer);
end;

procedure TForm1.btnGetAllSMSClick(Sender: TObject);
begin
  lvMessages.Clear();
  if rgStorage.ItemIndex = 0 then
  begin
    FSmsListStorage := Phone_SIM;
  end
  else
  begin
    FSmsListStorage := Phone_Memory;
  end;

  if (rgMessageFormat.ItemIndex = 0) then
    ZylGSM.GetAllSMS(FSmsListStorage, 4)
  else
    ZylGSM.GetAllSMSText(FSmsListStorage)
end;

procedure TForm1.btnDeleteSmsClick(Sender: TObject);
begin
  if (lvMessages.Selected <> nil) and (lvMessages.Selected.Index >= 0) and (ZylGSM.IsConnected <> spNone) then
  begin
    ZylGSM.DeleteSMS(FSmsListStorage, StrToInt(lvMessages.Selected.SubItems[3]));
    lvMessages.Items.Delete(lvMessages.Selected.Index);
  end;
end;

procedure TForm1.btnLoadContactsClick(Sender: TObject);
var
  i: Integer;
  item: TListItem;
begin
  lvContacts.Clear;
  if rgStorage.ItemIndex = 0 then
  begin
    ZylGSM.LoadPhoneBook(Phone_SIM);
    FContactListStorage := Phone_SIM;
  end
  else
  begin
    ZylGSM.LoadPhoneBook(Phone_Memory);
    FContactListStorage := Phone_MEMORY;
  end;
end;

procedure TForm1.ZylGSMContactLoad(Sender: TObject; const index: Integer;
  const name, phoneNumber, location: String);
var
  item: TListItem;
begin
  item := lvContacts.Items.Add;
  item.Caption := IntToStr(index);
  item.SubItems.Add(name);
  item.SubItems.Add(phoneNumber);  
end;

procedure TForm1.btnDelteContactClick(Sender: TObject);
begin
  if (lvContacts.Selected <> nil) and (lvContacts.Selected.Index >= 0) and (ZylGSM.IsConnected <> spNone) then
  begin
    ZylGSM.DeleteContact(FContactListStorage, StrToInt(lvContacts.Selected.Caption));
    lvContacts.Items.Delete(lvContacts.Selected.Index);
  end;
  //ZylGSM.AddContact(FContactListStorage, '0745628789', 'YouNobody');
end;

procedure TForm1.FormDblClick(Sender: TObject);
begin
  ShowMessage(ZylGSM.GetPhoneNumber);
end;

procedure TForm1.btnDetectAllClick(Sender: TObject);
var
  pPort: TCommPort;
  pBaudRate: TBaudRate;
  detectedPorts: TDeviceSettings;
  i: Integer;
  strResult: String;
begin
  FCancelDetect := False;
  detectedPorts := ZylGSM.FastDetectAllGSM();
  if detectedPorts.Count > 0 then
  begin
    strResult := '';
    for i := 0 to detectedPorts.Count - 1 do
    begin
      strResult := strResult + ZylGSM.CommPortToString(detectedPorts.Items[i].CommPort) + ', ' + IntToStr(ZylGSM.BaudRateToInt(detectedPorts.Items[i].BaudRate)) + #13#10;
    end;
    ShowMessage(strResult);
  end
  else
  begin
    ShowMessage('No GSM detected.');
  end;
  lblDetect.Caption := ''
end;

procedure TForm1.ZylGSMIdle(Sender: TObject);
begin
  Memo.Lines.Add('Idle');
end;

procedure TForm1.ZylGSMResume(Sender: TObject);
begin
  Memo.Lines.Add('Resume');
end;

procedure TForm1.ZylGSMTimeout(Sender: TObject);
begin
  Memo.Lines.Add('Timeout');
end;

procedure TForm1.rgStorageClick(Sender: TObject);
begin
  if rgStorage.ItemIndex = 0 then
    ZylGSM.StorageLocation := Phone_SIM
  else
    ZylGSM.StorageLocation := Phone_Memory;
end;

end.
